@@ -1,7 +1,7 @@
 package Log::ger::Output::LogAny;
 
-our $DATE = '2017-06-23'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2017-06-24'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use strict;
 use warnings;
@@ -17,7 +17,7 @@ sub get_hooks {
             sub {
                 my %args = @_;
 
-                return unless $args{target} eq 'package';
+                return [] unless $args{target} eq 'package';
                 my $pkg = $args{target_arg};
 
                 {
@@ -50,7 +50,7 @@ Log::ger::Output::LogAny - Send logs to Log::Any
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
